part of 'faq_bloc.dart';

abstract class FaqState extends Equatable {
  const FaqState();

  @override
  List<Object> get props => [];
}

class FaqInitial extends FaqState {
  const FaqInitial();
}

class FaqLoading extends FaqState {
  const FaqLoading();
}

class FaqReady extends FaqState {
  const FaqReady();
}

class FaqError extends FaqState {
  final String message;
  const FaqError({required this.message});

  @override
  List<Object> get props => [message];
}
